@@ -1,6 +1,6 @@
 ;;; forge-github.el --- Github support            -*- lexical-binding: t -*-
 
-;; Copyright (C) 2018-2021  Jonas Bernoulli
+;; Copyright (C) 2018-2022  Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <jonas@bernoul.li>
 ;; Maintainer: Jonas Bernoulli <jonas@bernoul.li>
@@ -85,13 +85,16 @@
      :auth 'forge
      :sparse selective-p)))
 
-(cl-defmethod forge--pull-topic ((repo forge-github-repository) topic)
+(cl-defmethod forge--pull-topic ((repo forge-github-repository)
+                                 (topic forge-topic))
   (let ((buffer (current-buffer))
         (fetch #'ghub-fetch-issue)
         (update #'forge--update-issue)
         (errorback (lambda (err _headers _status _req)
                      (when (equal (cdr (assq 'type (cadr err))) "NOT_FOUND")
-                       (forge--pull-topic repo topic t)))))
+                       (forge--pull-topic
+                        repo (forge-pullreq :repository (oref repo id)
+                                            :number (oref topic number)))))))
     (when (cl-typep topic 'forge-pullreq)
       (setq fetch #'ghub-fetch-pullreq)
       (setq update #'forge--update-pullreq)
@@ -144,6 +147,7 @@
                          (forge-issue :id         issue-id
                                       :repository (oref repo id)
                                       :number     .number)))))
+        (oset issue id         issue-id)
         (oset issue state      (pcase-exhaustive .state
                                  ("CLOSED" 'closed)
                                  ("OPEN"   'open)))
